@@ -4,11 +4,11 @@ from typing import List, Optional
 
 import regex as re
 from lang_trans.arabic import buckwalter
-from nesteddictionary import NestedDict
+from pelecanus import PelicanJson
 
 from .entity_mapper import EntityMapper
 from .fact import Fact
-from .parsers import AddressParser, ContactEmailNamePairParser, ContactEmailParser, ContactPhoneParserHighRecall, ContactPhoneParserHighPrecision, ContactPhoneParserStrict
+from .parsers import AddressParser, ContactEmailNamePairParser, ContactEmailParser, ContactPhoneParserHighPrecision, ContactPhoneParserHighRecall, ContactPhoneParserStrict
 from .russian_transliterator import Transliterate
 
 
@@ -109,10 +109,11 @@ class Document:
         root_key = "{}_mlp".format(list_of_path_keys[-1])
         path_to_mlp = list_of_path_keys[:-1] + [root_key] if len(list_of_path_keys) > 1 else [root_key]
         mlp_result = self.to_json()
-        nested_dict_wrapper = NestedDict(self.json_doc)
-        nested_dict_wrapper.insert(path_to_mlp, mlp_result["text"])
-        nested_dict_wrapper.insert(["texta_facts"], mlp_result["texta_facts"])
-        return json.loads(nested_dict_wrapper.dumps())
+        nested_dict_wrapper = PelicanJson(self.json_doc)
+        nested_dict_wrapper.set_nested_value(path_to_mlp, mlp_result["text"], force=True)
+        nested_dict_wrapper.set_nested_value(["texta_facts"], mlp_result["texta_facts"], force=True)
+
+        return nested_dict_wrapper.convert()
 
 
     def to_json(self) -> dict:
@@ -179,32 +180,38 @@ class Document:
                 )
                 self.__texta_facts.append(new_fact)
 
+
     def emails(self):
         text = self.get_words()
         emails = ContactEmailParser(text).parse()
         self.__texta_facts.extend((email.to_fact(Document.FACT_NAME_EMAIL, self.doc_path) for email in emails))
 
+
     def phone_strict(self):
         text = self.get_words()
         phone_numbers_strict = ContactPhoneParserStrict(text).parse()
         self.__texta_facts.extend((number.to_fact(Document.FACT_NAME_PHONE_STRICT, self.doc_path) for number in phone_numbers_strict))
-        
+
+
     def phone_high_recall(self):
         text = self.get_words()
         phone_numbers = ContactPhoneParserHighRecall(text, months=self.concat_resources["months"]).parse()
         self.__texta_facts.extend((number.to_fact(Document.FACT_NAME_PHONE_HIGH_RECALL, self.doc_path) for number in phone_numbers))
-        
+
+
     def phone_high_precision(self):
         text = self.get_words()
         phone_numbers_high_precision = ContactPhoneParserHighPrecision(text).parse()
         self.__texta_facts.extend((number.to_fact(Document.FACT_NAME_PHONE_HIGH_PRECISION, self.doc_path) for number in phone_numbers_high_precision))
-            
-    def addresses(self): 
+
+
+    def addresses(self):
         print("Hakkan aadresse otsima")
         text = self.get_words()
         addresses = AddressParser(text, self.stanza_entities, self.dominant_language_code).parse()
         self.__texta_facts.extend((addr.to_fact(Document.FACT_NAME_ADDRESS, self.doc_path) for addr in addresses))
 
+
     def transliteration(self):
         if self.dominant_language_code in Document.langs_to_transliterate:
             for word in self.stanza_words:
@@ -291,6 +298,7 @@ class Document:
                     )
                     self.__texta_facts.append(new_fact)
 
+
     def namemail(self):
         """
         Find name-email pairs.
@@ -526,6 +534,7 @@ class Document:
                 new_bounds.append(new_fact)
         return new_bounds
 
+
     def add_phone_high_recall(self, facts):
         """
         remove previous phone facts
@@ -540,9 +549,10 @@ class Document:
         new_facts.extend((number.to_fact(Document.FACT_NAME_PHONE_HIGH_RECALL, self.doc_path) for number in phone_numbers))
         return new_facts
 
+
     def bounded(self):
         facts = self.remove_duplicate_facts_by_span(self.__texta_facts)
-        facts = self.add_phone_high_recall(facts) #bounded uses only ContactPhoneParserHighRecall results.
+        facts = self.add_phone_high_recall(facts)  # bounded uses only ContactPhoneParserHighRecall results.
         new_bounded = self.bound_close_ones(facts)
         new_bounded = self.remove_overlaping_in_bounded(new_bounded)
         new_bounded = self.concatenate_subset_bounds(new_bounded)
