@@ -9,7 +9,7 @@ import regex as re
 import stanza
 from bs4 import BeautifulSoup
 from langdetect import detect
-from nesteddictionary import NestedDict
+from pelecanus import PelicanJson
 
 from texta_mlp.document import Document
 from texta_mlp.entity_mapper import EntityMapper
@@ -31,7 +31,7 @@ CONCATENATOR_DATA_FILES = (
 )
 
 DEFAULT_RESOURCE_DIR = os.path.join(os.getcwd(), "data")
-SUPPORTED_ANALYZERS =  (
+SUPPORTED_ANALYZERS = (
     "lemmas",
     "pos_tags",
     "transliteration",
@@ -47,10 +47,14 @@ SUPPORTED_ANALYZERS =  (
 
 class MLP:
 
-    def __init__(self, language_codes=DEFAULT_LANG_CODES, default_language_code=DEFAULT_LANG_CODES[0],
-                 use_default_language_code=True, resource_dir: str = DEFAULT_RESOURCE_DIR, logging_level="error"):
-
-
+    def __init__(
+            self,
+            language_codes=DEFAULT_LANG_CODES,
+            default_language_code=DEFAULT_LANG_CODES[0],
+            use_default_language_code=True,
+            resource_dir: str = DEFAULT_RESOURCE_DIR,
+            logging_level="error"
+    ):
         self.supported_langs = language_codes
         self.logger = logging.getLogger()
         self.default_lang = default_language_code
@@ -136,7 +140,7 @@ class MLP:
         return text
 
 
-    def detect_language(self, text):
+    def detect_language(self, text: str):
         """
         Detects language of input text.
         If language not in supported list, language is defaulted or exception raised.
@@ -157,19 +161,14 @@ class MLP:
         return lang
 
 
-    def generate_document(self, raw_text, analyzers, json_object=None, doc_paths="text", lang=None):
+    def generate_document(self, raw_text: str, analyzers: List[str], json_object: dict = None, doc_paths="text", lang=None):
         processed_text = MLP.normalize_input_text(raw_text)
         # detect language
         if not lang:
             lang = self.detect_language(processed_text)
-        # check if processed text not empty
-        if processed_text:
-            # Separate all the words into a separate list.
-            words = self._get_stanza_tokens(lang, processed_text)
-            entities = self._get_stanza_ner(lang, processed_text)
-        else:
-            words = []
-            entities = []
+
+        words = self._get_stanza_tokens(lang, processed_text) if processed_text else []
+        entities = self._get_stanza_ner(lang, processed_text) if processed_text and ("ner" in analyzers) else []
 
         document = Document(
             original_text=processed_text,
@@ -268,6 +267,21 @@ class MLP:
         return document["text"]["lemmas"]
 
 
+    def __parse_doc_texts(self, doc_path: str, document: dict) -> list:
+        """
+        Function for parsing text values from a nested dictionary given a field path.
+        :param doc_path: Dot separated path of fields to the value we wish to parse.
+        :param document: Document to be worked on.
+        :return: List of text fields that will be processed by MLP.
+        """
+        wrapper = PelicanJson(document)
+        doc_path_as_list = doc_path.split(".")
+        doc_texts = wrapper.safe_get_nested_value(doc_path_as_list, default=[])
+        doc_texts = [] if doc_texts is None else doc_texts
+        doc_texts = [doc_texts] if isinstance(doc_texts, str) else doc_texts
+        return doc_texts
+
+
     def process_docs(self, docs: List[dict], doc_paths: List[str], analyzers=["all"]):
         """
         :param docs: Contains tuples with two dicts inside them, the first being the document to be analyzed and the second is the meta information that corresponds to the document for transport purposes later on.
@@ -281,8 +295,7 @@ class MLP:
             for doc_path in doc_paths:
                 # Traverse the (possible) nested dicts and extract their text values from it as a list of strings.
                 # Since the nested doc_path could lead to a list there are multiple pieces of text which would be needed to process.
-                doc_texts = NestedDict(document).get(doc_path)
-                doc_texts = [doc_texts] if isinstance(doc_texts, str) else doc_texts
+                doc_texts = self.__parse_doc_texts(doc_path, document)
                 for raw_text in doc_texts:
                     analyzers = self._load_analyzers(analyzers, SUPPORTED_ANALYZERS)
                     doc = self.generate_document(raw_text, analyzers, document, doc_paths=doc_path)
