@@ -236,9 +236,5 @@ class AddressParser(AbstractParser):
         # pattern to search potential addresses
         if self.language == 'ru':
             return self._parse_ru()
-        if self.language in ['en', 'et', 'ar']:
-            return self._parse_others()
-
         else:
-            raise NotImplementedError(
-                f'{self.__class__.__name__}.parse not implemented for language {self.language!r}')
+            return self._parse_others()
